@@ -1,4 +1,4 @@
-from pulsar.schema import Record, String, Map, Double
+from pulsar.schema import Record, String, Map, Double, Array
 
 from ..core.metadata import Metadata
 from ..core.topic import topic
@@ -10,7 +10,7 @@ from ..core.topic import topic
 class ExtractedObject(Record):
     metadata = Metadata()
     schema_name = String()  # Which schema this object belongs to
-    values = Map(String())  # Field name -> value
+    values = Array(Map(String()))  # Array of objects, each object is field name -> value
     confidence = Double()
     source_span = String()  # Text span where object was found
 
