@@ -9,4 +9,7 @@ from .library import *
 from .lookup import *
 from .nlp_query import *
 from .structured_query import *
-from .objects_query import *
\ No newline at end of file
+from .objects_query import *
+from .diagnosis import *
+from .collection import *
+from .storage import *
\ No newline at end of file
